# Edit this configuration file to define what should be installed on
# your system.  Help is available in the configuration.nix(5) man page
# and in the NixOS manual (accessible by running ‘nixos-help’).

{ config, pkgs, lib, ... }:

{
  imports =
    [ ../../../lib/lxc-container.nix
    ../../../lib/shared.nix
    ../../../lib/admins.nix
  ];

  environment.systemPackages = with pkgs; [
    ncmpcpp
  ];

  fileSystems."/mnt/music" = { fsType = "nfs"; device = "172.22.99.10:/mnt/zroot/storage/rpool/Music"; };

  networking.hostName = "mpd-index";

  services.openssh = {
    enable = true;
    permitRootLogin = "yes";
  };

  services.mpd = {
    enable = true;
    user = "mpd";
    group = "audio";
    network = {
      listenAddress = "any";
      port = 6600;
    };
    musicDirectory  = "/mnt/music";
    extraConfig = ''
      default_permissions "read,add,control,admin"

      input {
        plugin "curl"
      }

      audio_output {
        type "null"
        name "My Null Output"
      }

      filesystem_charset "UTF-8"
    '';
  };

  system.stateVersion = "18.09"; # Did you read the comment?

}
